#
# spec file for package perl-File-Path-Tiny
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name File-Path-Tiny
Name:           perl-File-Path-Tiny
Version:        1.0.0
Release:        1.3
# 1.0 -> normalize -> 1.0.0
%define cpan_version 1.0
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Recursive versions of mkdir() and rmdir() without as much overhead as Fi[cut]
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DM/DMUEY/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::Exception)
Requires:       perl(Test::Exception)
Provides:       perl(File::Path::Tiny) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
The goal here is simply to provide recursive versions of mkdir() and
rmdir() with as little code and overhead as possible.

This module is in no way meant to derogate File::Path and is in no way an
endorsement to go out and replace all use of File::Path with
File::Path::Tiny.

File::Path is very good at what it does but there's simply a lot happening
that we can do without much of the time.

Here are some things File::Path has/does that this module attempts to do
without:

* * multiple interfaces

Backwards compatibility brings in a lot of code and logic that we don't
need from here on out.

* * chdir()s

It forces a ton of chdir()s which could leave you somewhere you're not
planning on being and requires much more overhead to do.

This module provides a way to disable that if you know it is safe to do so
in your circumstance.

* * can croak not allowing you to detect and handle failure

Just let me handle errors how I want. Don't make my entire app die or have
to wrap it in an eval

The exception here is the security checks can croak, which is what you
want. See DIAGNOSTICS for more info.

* * A well intentioned output system

Just let me do the output how I want. (Nothing, As HTML, print to a
filehandle, etc...)

* * A well intentioned and experimental (IE subject to change) error
  handling system.

Just keep it simple and detect failure via a boolean check and do what I
want with the error. See "How can I make/remove multiple paths?"

* * According to its POD, removing a tree is apparently not safe unless you
  tell it to be with the ‘safe’ or 'keep_root' attributes.

Seems like that should just happen, I don't want to worry about
accidentally removing / when I pass it /tmp

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README

%changelog
* Thu Feb  6 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Fri Feb  5 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.0
  see /usr/share/doc/packages/perl-File-Path-Tiny/Changes
  1.0  2021-02-04 13:53:54
  - rt 125502: fix empty_dir() fast-mode, thanks ishigaki!
  - f749173 Stop using bareword handle (still ::Tiny since perl is newer)
* Wed Feb  7 2018 coolo@suse.com
- updated to 0.9
  see /usr/share/doc/packages/perl-File-Path-Tiny/Changes
  0.9  2017-12-29 16:17:42
  - Do chdir() for security reasons by default
  - Stop emptying/removing a path if it is changed out from underneath us
  - rt 96843: Add SEE ALSO section
  - prereq and unit test fixups
  - Unit tests for symlink toggling protection
* Wed Jan 27 2016 coolo@suse.com
- updated to 0.8
  see /usr/share/doc/packages/perl-File-Path-Tiny/Changes
  0.8  2016-01-26 14:44:57
  - rt 88849: allow multiple processes to operate on the same paths (thanks HELENA!)
  - Add github to POD
  - rt 96842: Fix mk() to work correctly w/ UNC paths on windows (thanks MITHUN!)
* Fri Oct  4 2013 coolo@suse.com
- updated to 0.7
  - add =encoding to POD due to test failure on certain boxes
  - add several perl, pkg, and pod tests
  - add mk_parent()
* Tue Jun  4 2013 coolo@suse.com
- updated to 0.5
    rt 79472 (thanks Lachlan!) fix absolute path bug introduced in 0.4
    rt 79345 (thanks Gian!): Failed to recursively create dir if the first part solves to false
    rt 76061 No LICENSE in META.yml
    rt 68950 break out rm() code into empty() type function, use it in rm()
    rt 51728 Missing colon in synopsis
    rt 75688 using deprecated for qw() in 00.load.t
    perltidy
* Mon Feb 13 2012 coolo@suse.com
- regenerate with cpanspec
* Fri Sep 30 2011 pascal.bleser@opensuse.org
- initial version (0.1)
